@@ -32,8 +32,10 @@
 #include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
+#include "egg-color.h"
+#include "egg-array-float.h"
+#include "egg-unique.h"
 
-#include "gpm-array-float.h"
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
 #include "gpm-upower.h"
@@ -47,7 +49,7 @@ gchar *current_device = NULL;
 static const gchar *history_type;
 static const gchar *stats_type;
 static guint history_time;
-static GSettings *settings;
+static GConfClient *gconf_client;
 static gfloat sigma_smoothing = 0.0f;
 static UpWakeups *wakeups = NULL;
 static GtkWidget *graph_history = NULL;
@@ -113,7 +115,7 @@ enum {
  * gpm_stats_button_help_cb:
  **/
 static void
-gpm_stats_button_help_cb (GtkWidget *widget, gpointer user_data)
+gpm_stats_button_help_cb (GtkWidget *widget, gboolean data)
 {
 	gpm_help_display ("statistics");
 }
@@ -154,7 +156,7 @@ gpm_stats_add_devices_columns (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	g_object_set (renderer, "stock-size", GTK_ICON_SIZE_DIALOG, NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("Image"), renderer,
-							   "gicon", GPM_DEVICES_COLUMN_ICON, NULL);
+							   "icon-name", GPM_DEVICES_COLUMN_ICON, NULL);
 	gtk_tree_view_append_column (treeview, column);
 
 	/* column for text */
@@ -234,24 +236,24 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 	GpmPointObj *point;
 	GpmPointObj *point_new;
 	GPtrArray *new;
-	GpmArrayFloat *raw;
-	GpmArrayFloat *convolved;
-	GpmArrayFloat *outliers;
-	GpmArrayFloat *gaussian = NULL;
+	EggArrayFloat *raw;
+	EggArrayFloat *convolved;
+	EggArrayFloat *outliers;
+	EggArrayFloat *gaussian = NULL;
 
-	/* convert the y data to a GpmArrayFloat array */
-	raw = gpm_array_float_new (list->len);
+	/* convert the y data to a EggArrayFloat array */
+	raw = egg_array_float_new (list->len);
 	for (i=0; i<list->len; i++) {
 		point = (GpmPointObj *) g_ptr_array_index (list, i);
-		gpm_array_float_set (raw, i, point->y);
+		egg_array_float_set (raw, i, point->y);
 	}
 
 	/* remove any outliers */
-	outliers = gpm_array_float_remove_outliers (raw, 3, 0.1);
+	outliers = egg_array_float_remove_outliers (raw, 3, 0.1);
 
 	/* convolve with gaussian */
-	gaussian = gpm_array_float_compute_gaussian (15, sigma_smoothing);
-	convolved = gpm_array_float_convolve (outliers, gaussian);
+	gaussian = egg_array_float_compute_gaussian (15, sigma_smoothing);
+	convolved = egg_array_float_convolve (outliers, gaussian);
 
 	/* add the smoothed data back into a new array */
 	new = g_ptr_array_new_with_free_func ((GDestroyNotify) gpm_point_obj_free);
@@ -260,15 +262,15 @@ gpm_stats_update_smooth_data (GPtrArray *list)
 		point_new = g_new0 (GpmPointObj, 1);
 		point_new->color = point->color;
 		point_new->x = point->x;
-		point_new->y = gpm_array_float_get (convolved, i);
+		point_new->y = egg_array_float_get (convolved, i);
 		g_ptr_array_add (new, point_new);
 	}
 
 	/* free data */
-	gpm_array_float_free (gaussian);
-	gpm_array_float_free (raw);
-	gpm_array_float_free (convolved);
-	gpm_array_float_free (outliers);
+	egg_array_float_free (gaussian);
+	egg_array_float_free (raw);
+	egg_array_float_free (convolved);
+	egg_array_float_free (outliers);
 
 	return new;
 }
@@ -402,7 +404,7 @@ gpm_stats_update_info_page_details (UpDevice *device)
 	gpm_stats_add_info_data (_("Device"), device_path);
 	g_free (device_path);
 
-	gpm_stats_add_info_data (_("Type"), gpm_device_kind_to_localised_string (kind, 1));
+	gpm_stats_add_info_data (_("Type"), gpm_device_kind_to_localised_text (kind, 1));
 	if (vendor != NULL && vendor[0] != '\0')
 		gpm_stats_add_info_data (_("Vendor"), vendor);
 	if (model != NULL && model[0] != '\0')
@@ -619,18 +621,18 @@ gpm_stats_update_info_page_history (UpDevice *device)
 		point->x = (gint32) up_history_item_get_time (item) - offset;
 		point->y = up_history_item_get_value (item);
 		if (up_history_item_get_state (item) == UP_DEVICE_STATE_CHARGING)
-			point->color = gpm_color_from_rgb (255, 0, 0);
+			point->color = egg_color_from_rgb (255, 0, 0);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_DISCHARGING)
-			point->color = gpm_color_from_rgb (0, 0, 255);
+			point->color = egg_color_from_rgb (0, 0, 255);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_PENDING_CHARGE)
-			point->color = gpm_color_from_rgb (200, 0, 0);
+			point->color = egg_color_from_rgb (200, 0, 0);
 		else if (up_history_item_get_state (item) == UP_DEVICE_STATE_PENDING_DISCHARGE)
-			point->color = gpm_color_from_rgb (0, 0, 200);
+			point->color = egg_color_from_rgb (0, 0, 200);
 		else {
 			if (g_strcmp0 (history_type, GPM_HISTORY_RATE_VALUE) == 0)
-				point->color = gpm_color_from_rgb (255, 255, 255);
+				point->color = egg_color_from_rgb (255, 255, 255);
 			else
-				point->color = gpm_color_from_rgb (0, 255, 0);
+				point->color = egg_color_from_rgb (0, 255, 0);
 		}
 		g_ptr_array_add (new, point);
 	}
@@ -722,7 +724,7 @@ gpm_stats_update_info_page_stats (UpDevice *device)
 			point->y = up_stats_item_get_value (item);
 		else
 			point->y = up_stats_item_get_accuracy (item);
-		point->color = gpm_color_from_rgb (255, 0, 0);
+		point->color = egg_color_from_rgb (255, 0, 0);
 		g_ptr_array_add (new, point);
 	}
 
@@ -909,43 +911,57 @@ gpm_stats_format_details (UpWakeupItem *item)
 
 	/* try to make the wakeup type nicer */
 	} else if (g_str_has_prefix (data, "__mod_timer")) {
-		/* TRANSLATORS: a timer is something that fires periodically */
+		/* TRANSLATORS: a timer is something that fires periodically.
+		 * The parameter is a process name, e.g. "firefox-bin".
+		 * This is shown when the timer wakes up. */
 		details = g_strdup_printf (_("Timer %s"), data+12);
 	} else if (g_str_has_prefix (data, "mod_timer")) {
-		/* TRANSLATORS: a timer is something that fires periodically */
+		/* TRANSLATORS: a timer is something that fires periodically.
+		 * The parameter is a process name, e.g. "firefox-bin".
+		 * This is shown when the timer wakes up. */
 		details = g_strdup_printf (_("Timer %s"), data+10);
 	} else if (g_str_has_prefix (data, "hrtimer_start_expires")) {
-		/* TRANSLATORS: a timer is something that fires periodically */
+		/* TRANSLATORS: a timer is something that fires periodically.
+		 * The parameter is a process name, e.g. "firefox-bin".
+		 * This is shown when the timer wakes up. */
 		details = g_strdup_printf (_("Timer %s"), data+22);
 	} else if (g_str_has_prefix (data, "hrtimer_start")) {
-		/* TRANSLATORS: a timer is something that fires periodically */
+		/* TRANSLATORS: a timer is something that fires periodically.
+		 * The parameter is a process name, e.g. "firefox-bin".
+		 * This is shown when the timer wakes up. */
 		details = g_strdup_printf (_("Timer %s"), data+14);
 	} else if (g_str_has_prefix (data, "do_setitimer")) {
-		/* TRANSLATORS: a timer is something that fires periodically */
+		/* TRANSLATORS: a timer is something that fires periodically.
+		 * The parameter is a process name, e.g. "firefox-bin".
+		 * This is shown when the timer wakes up. */
 		details = g_strdup_printf (_("Timer %s"), data+10);
 	} else if (g_str_has_prefix (data, "do_nanosleep")) {
-		/* TRANSLATORS: this is a task that's woken up from sleeping */
+		/* TRANSLATORS: the parameter is the name of task that's woken up from sleeping.
+		 * This is shown when the task wakes up. */
 		details = g_strdup_printf (_("Sleep %s"), data+13);
 	} else if (g_str_has_prefix (data, "enqueue_task_rt")) {
-		/* TRANSLATORS: this is a new realtime task */
+		/* TRANSLATORS: this is the name of a new realtime task. */
 		details = g_strdup_printf (_("New task %s"), data+16);
 	} else if (g_str_has_prefix (data, "futex_wait")) {
-		/* TRANSLATORS: this is a task thats woken to check state */
+		/* TRANSLATORS: this is the name of a task that's woken to check state.
+		 * This is shown when the task wakes up. */
 		details = g_strdup_printf (_("Wait %s"), data+11);
 	} else if (g_str_has_prefix (data, "queue_delayed_work_on")) {
-		/* TRANSLATORS: a work queue is a list of work that has to be done */
+		/* TRANSLATORS: this is the name of a work queue.
+		 * A work queue is a list of work that has to be done. */
 		details = g_strdup_printf (_("Work queue %s"), data+22);
 	} else if (g_str_has_prefix (data, "queue_delayed_work")) {
-		/* TRANSLATORS: a work queue is a list of work that has to be done */
+		/* TRANSLATORS: this is the name of a work queue.
+		 * A work queue is a list of work that has to be done. */
 		details = g_strdup_printf (_("Work queue %s"), data+19);
 	} else if (g_str_has_prefix (data, "dst_run_gc")) {
 		/* TRANSLATORS: this is when the networking subsystem clears out old entries */
 		details = g_strdup_printf (_("Network route flush %s"), data+11);
 	} else if (g_str_has_prefix (data, "usb_hcd_poll_rh_status")) {
-		/* TRANSLATORS: activity on the USB bus */
+		/* TRANSLATORS: this is the name of an activity on the USB bus */
 		details = g_strdup_printf (_("USB activity %s"), data+23);
 	} else if (g_str_has_prefix (data, "schedule_hrtimeout_range")) {
-		/* TRANSLATORS: we've timed out of an aligned timer */
+		/* TRANSLATORS: we've timed out of an aligned timer, with the name */
 		details = g_strdup_printf (_("Wakeup %s"), data+25);
 	} else if (g_str_has_prefix (data, "Local timer interrupts")) {
 		/* TRANSLATORS: interupts on the system required for basic operation */
@@ -1080,7 +1096,7 @@ gpm_stats_set_title (GtkWindow *window, gint page_num)
  * gpm_stats_notebook_changed_cb:
  **/
 static void
-gpm_stats_notebook_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, gint page_num, gpointer user_data)
+gpm_stats_notebook_changed_cb (GtkNotebook *notebook, gpointer page, gint page_num, gpointer user_data)
 {
 	UpDevice *device;
 	GtkWidget *widget;
@@ -1090,7 +1106,7 @@ gpm_stats_notebook_changed_cb (GtkNotebook *notebook, GtkNotebookPage *page, gin
 	gpm_stats_set_title (GTK_WINDOW (widget), page_num);
 
 	/* save page in gconf */
-	g_settings_set_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER, page_num);
+	gconf_client_set_int (gconf_client, GPM_CONF_INFO_PAGE_NUMBER, page_num, NULL);
 
 	if (current_device == NULL)
 		return;
@@ -1122,7 +1138,7 @@ gpm_stats_button_update_ui (void)
  * gpm_stats_devices_treeview_clicked_cb:
  **/
 static void
-gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer user_data)
+gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean data)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -1134,7 +1150,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer use
 		gtk_tree_model_get (model, &iter, GPM_DEVICES_COLUMN_ID, &current_device, -1);
 
 		/* save device in gconf */
-		g_settings_set_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE, current_device);
+		gconf_client_set_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, current_device, NULL);
 
 		/* show transaction_id */
 		egg_debug ("selected row is: %s", current_device);
@@ -1154,6 +1170,17 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gpointer use
 	}
 }
 
+/**
+ * gpm_stats_window_activated_cb
+ **/
+static void
+gpm_stats_window_activated_cb (EggUnique *egg_unique, gpointer data)
+{
+	GtkWidget *widget;
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
+	gtk_window_present (GTK_WINDOW (widget));
+}
+
 /**
  * gpm_stats_add_device:
  **/
@@ -1163,7 +1190,7 @@ gpm_stats_add_device (UpDevice *device)
 	const gchar *id;
 	GtkTreeIter iter;
 	const gchar *text;
-	GIcon *icon;
+	const gchar *icon;
 	UpDeviceKind kind;
 
 	/* get device properties */
@@ -1172,15 +1199,14 @@ gpm_stats_add_device (UpDevice *device)
 		      NULL);
 
 	id = up_device_get_object_path (device);
-	text = gpm_device_kind_to_localised_string (kind, 1);
-	icon = gpm_upower_get_device_icon (device, FALSE);
+	text = gpm_device_kind_to_localised_text (kind, 1);
+	icon = gpm_upower_get_device_icon (device);
 
 	gtk_list_store_append (list_store_devices, &iter);
 	gtk_list_store_set (list_store_devices, &iter,
 			    GPM_DEVICES_COLUMN_ID, id,
 			    GPM_DEVICES_COLUMN_TEXT, text,
 			    GPM_DEVICES_COLUMN_ICON, icon, -1);
-	g_object_unref (icon);
 }
 
 /**
@@ -1298,7 +1324,7 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	g_free (value);
 
 	/* save to gconf */
-	g_settings_set_string (settings, GPM_SETTINGS_INFO_HISTORY_TYPE, history_type);
+	gconf_client_set_string (gconf_client, GPM_CONF_INFO_HISTORY_TYPE, history_type, NULL);
 }
 
 /**
@@ -1349,7 +1375,7 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	g_free (value);
 
 	/* save to gconf */
-	g_settings_set_string (settings, GPM_SETTINGS_INFO_STATS_TYPE, stats_type);
+	gconf_client_set_string (gconf_client, GPM_CONF_INFO_STATS_TYPE, stats_type, NULL);
 }
 
 /**
@@ -1374,7 +1400,7 @@ gpm_stats_range_combo_changed (GtkWidget *widget, gpointer data)
 		g_assert (FALSE);
 
 	/* save to gconf */
-	g_settings_set_int (settings, GPM_SETTINGS_INFO_HISTORY_TIME, history_time);
+	gconf_client_set_int (gconf_client, GPM_CONF_INFO_HISTORY_TIME, history_time, NULL);
 
 	gpm_stats_button_update_ui ();
 	g_free (value);
@@ -1389,7 +1415,7 @@ gpm_stats_smooth_checkbox_history_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_SMOOTH, checked);
+	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_SMOOTH, checked, NULL);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1402,7 +1428,7 @@ gpm_stats_smooth_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_SMOOTH, checked);
+	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_SMOOTH, checked, NULL);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1415,7 +1441,7 @@ gpm_stats_points_checkbox_history_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_POINTS, checked);
+	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_POINTS, checked, NULL);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1428,7 +1454,7 @@ gpm_stats_points_checkbox_stats_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean checked;
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-	g_settings_set_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_POINTS, checked);
+	gconf_client_set_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_POINTS, checked, NULL);
 	gpm_stats_button_update_ui ();
 }
 
@@ -1489,25 +1515,6 @@ gpm_stats_highlight_device (const gchar *object_path)
 	}
 }
 
-/**
- * gpm_stats_delete_event_cb:
- **/
-static gboolean
-gpm_stats_delete_event_cb (GtkWidget *widget, GdkEvent *event, GtkApplication *application)
-{
-	gtk_application_quit (application);
-	return FALSE;
-}
-
-/**
- * gpm_stats_button_close_cb:
- **/
-static void
-gpm_stats_button_close_cb (GtkWidget *widget, GtkApplication *application)
-{
-	gtk_application_quit (application);
-}
-
 /**
  * main:
  **/
@@ -1519,7 +1526,7 @@ main (int argc, char *argv[])
 	GtkBox *box;
 	GtkWidget *widget;
 	GtkTreeSelection *selection;
-	GtkApplication *application;
+	EggUnique *egg_unique;
 	gboolean ret;
 	UpClient *client;
 	GPtrArray *devices;
@@ -1564,14 +1571,19 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
-	application = gtk_application_new ("org.gnome.PowerManager.Statistics", &argc, &argv);
+	egg_unique = egg_unique_new ();
+	ret = egg_unique_assign (egg_unique, "org.gnome.PowerManager.Statistics");
+	if (!ret)
+		goto unique_out;
+	g_signal_connect (egg_unique, "activated",
+			  G_CALLBACK (gpm_stats_window_activated_cb), NULL);
 
 	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* get data from gconf */
-	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
+	gconf_client = gconf_client_get_default ();
 
 	/* get UI */
 	builder = gtk_builder_new ();
@@ -1596,17 +1608,14 @@ main (int argc, char *argv[])
 	gtk_widget_show (graph_statistics);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
-	gtk_application_add_window (application, GTK_WINDOW (widget));
 	gtk_window_set_default_size (GTK_WINDOW(widget), 800, 500);
 	gtk_window_set_default_icon_name (GPM_STOCK_APP_ICON);
 
 	/* Get the main window quit */
-	g_signal_connect (widget, "delete-event",
-			  G_CALLBACK (gpm_stats_delete_event_cb), application);
+	g_signal_connect_swapped (widget, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
-	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpm_stats_button_close_cb), application);
+	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
 	gtk_widget_grab_default (widget);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
@@ -1614,38 +1623,38 @@ main (int argc, char *argv[])
 			  G_CALLBACK (gpm_stats_button_help_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_smooth_history"));
-	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_SMOOTH);
+	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_SMOOTH, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_smooth_checkbox_history_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_smooth_stats"));
-	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_SMOOTH);
+	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_SMOOTH, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_smooth_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_points_history"));
-	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_HISTORY_GRAPH_POINTS);
+	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_HISTORY_GRAPH_POINTS, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_points_checkbox_history_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_points_stats"));
-	checked = g_settings_get_boolean (settings, GPM_SETTINGS_INFO_STATS_GRAPH_POINTS);
+	checked = gconf_client_get_bool (gconf_client, GPM_CONF_INFO_STATS_GRAPH_POINTS, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), checked);
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (gpm_stats_points_checkbox_stats_cb), NULL);
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "notebook1"));
-	page = g_settings_get_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER);
+	page = gconf_client_get_int (gconf_client, GPM_CONF_INFO_PAGE_NUMBER, NULL);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), page);
 	g_signal_connect (widget, "switch-page",
 			  G_CALLBACK (gpm_stats_notebook_changed_cb), NULL);
 
 	/* create list stores */
 	list_store_info = gtk_list_store_new (GPM_INFO_COLUMN_LAST, G_TYPE_STRING, G_TYPE_STRING);
-	list_store_devices = gtk_list_store_new (GPM_DEVICES_COLUMN_LAST, G_TYPE_ICON,
+	list_store_devices = gtk_list_store_new (GPM_DEVICES_COLUMN_LAST, G_TYPE_STRING,
 						 G_TYPE_STRING, G_TYPE_STRING);
 	list_store_wakeups = gtk_list_store_new (GPM_WAKEUPS_COLUMN_LAST, G_TYPE_STRING,
 						 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
@@ -1680,14 +1689,14 @@ main (int argc, char *argv[])
 	gpm_stats_add_wakeups_columns (GTK_TREE_VIEW (widget));
 	gtk_tree_view_columns_autosize (GTK_TREE_VIEW (widget)); /* show */
 
-	history_type = g_settings_get_string (settings, GPM_SETTINGS_INFO_HISTORY_TYPE);
-	history_time = g_settings_get_int (settings, GPM_SETTINGS_INFO_HISTORY_TIME);
+	history_type = gconf_client_get_string (gconf_client, GPM_CONF_INFO_HISTORY_TYPE, NULL);
+	history_time = gconf_client_get_int (gconf_client, GPM_CONF_INFO_HISTORY_TIME, NULL);
 	if (history_type == NULL)
 		history_type = GPM_HISTORY_CHARGE_VALUE;
 	if (history_time == 0)
 		history_time = GPM_HISTORY_HOUR_VALUE;
 
-	stats_type = g_settings_get_string (settings, GPM_SETTINGS_INFO_STATS_TYPE);
+	stats_type = gconf_client_get_string (gconf_client, GPM_CONF_INFO_STATS_TYPE, NULL);
 	if (stats_type == NULL)
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
 
@@ -1740,19 +1749,19 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (widget), "changed",
 			  G_CALLBACK (gpm_stats_range_combo_changed), NULL);
 
+	client = up_client_new ();
+	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), NULL);
+	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), NULL);
+	g_signal_connect (client, "device-changed", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
 
 	wakeups = up_wakeups_new ();
 	g_signal_connect (wakeups, "data-changed", G_CALLBACK (gpm_stats_data_changed_cb), NULL);
 
 	/* coldplug */
-	client = up_client_new ();
 	ret = up_client_enumerate_devices_sync (client, NULL, NULL);
 	if (!ret)
 		goto out;
 	devices = up_client_get_devices (client);
-	g_signal_connect (client, "device-added", G_CALLBACK (gpm_stats_device_added_cb), NULL);
-	g_signal_connect (client, "device-removed", G_CALLBACK (gpm_stats_device_removed_cb), NULL);
-	g_signal_connect (client, "device-changed", G_CALLBACK (gpm_stats_device_changed_cb), NULL);
 
 	/* add devices in visually pleasing order */
 	for (j=0; j<UP_DEVICE_KIND_LAST; j++) {
@@ -1772,21 +1781,18 @@ main (int argc, char *argv[])
 	}
 
 	if (last_device == NULL)
-		last_device = g_settings_get_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE);
+		last_device = gconf_client_get_string (gconf_client, GPM_CONF_INFO_LAST_DEVICE, NULL);
 
 	/* has capability to measure wakeups */
 	ret = up_wakeups_get_has_capability (wakeups);
 	if (ret) {
 		GtkTreeIter iter;
-		GIcon *icon;
-		icon = g_themed_icon_new ("computer");
 		gtk_list_store_append (list_store_devices, &iter);
 		gtk_list_store_set (list_store_devices, &iter,
 				    GPM_DEVICES_COLUMN_ID, "wakeups",
 				    /* TRANSLATORS: the icon for the CPU */
 				    GPM_DEVICES_COLUMN_TEXT, _("Processor"),
-				    GPM_DEVICES_COLUMN_ICON, icon, -1);
-		g_object_unref (icon);
+				    GPM_DEVICES_COLUMN_ICON, "computer", -1);
 	}
 
 	/* set the correct focus on the last device */
@@ -1804,16 +1810,16 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_stats"));
 	gtk_widget_show (widget);
 
-	/* run */
-	gtk_application_run (application);
+	gtk_main ();
 
 out:
-	g_object_unref (settings);
+	g_object_unref (gconf_client);
 	g_object_unref (client);
 	g_object_unref (wakeups);
 	g_object_unref (builder);
 	g_object_unref (list_store_info);
-	g_object_unref (application);
+unique_out:
+	g_object_unref (egg_unique);
 	g_free (last_device);
 	return 0;
 }
